@@ -7,24 +7,26 @@
 # @Date   :  2020-10-29 13:38:36
 # @Description :  Powered by GitOPEN
 
-__version__ = "0.3.10"
+__version__ = "0.3.11"
 
 import asyncio
 import json
 import time
-from pathlib import Path, PosixPath
-from types import FunctionType
-from typing import Optional
+from pathlib import Path
+from typing import Callable, Iterable, List, Optional, Union
 
 from gitopenlib.utils import basics as gb
 
 
-def new_dirs(dir_paths: Optional[str or list]):
+def new_dirs(dir_paths: Union[str, List[str]]) -> List[str]:
     """
     初始化文件夹，检验文件夹的存在状态，并返回准备好的文件夹路径。
 
     Args:
-        dir_paths (str or list): 字符串类型的全路径，可以为单个路径，也可以放入列表中，批量创建。
+        dir_paths: 字符串类型的全路径，可以为单个路径，也可以放入列表中，批量创建。
+
+    Returns:
+        包含创建的文件夹路径字符串的list
     """
     if isinstance(dir_paths, str):
         dir_paths = [dir_paths]
@@ -37,20 +39,20 @@ def new_dirs(dir_paths: Optional[str or list]):
 
 
 def get_paths_from_dir(
-    dirs: Optional[str or list],
-    types: Optional[str or list] = None,
+    dirs: Union[str, List[str]],
+    types: Optional[Union[str, List[str]]] = None,
     recusive: bool = False,
-):
+) -> List[str]:
     """
     从指定目录下获取所有指定扩展名文件的路径
 
     Args:
-        dirs (list): 文件夹路径（绝对路径），单个用str表示，多个用list
-        types (types): 指定文件的扩展名，单个用str表示，多个用list，默认为None，表示所有类型文件
-        recusive (bool): 默认为False，不递归子文件夹
+        dirs: 文件夹路径（绝对路径），单个用str表示，多个用list
+        types: 指定文件的扩展名，单个用str表示，多个用list，默认为None，表示所有类型文件
+        recusive: 默认为False，不递归子文件夹
 
     Returns:
-        list: 文件路径字符串列表
+        文件路径字符串列表
     """
 
     if isinstance(dirs, str):
@@ -74,28 +76,25 @@ def get_paths_from_dir(
 
 
 def file_writer(
-    lines: Optional[str or list],
-    dir_path: Optional[str or Path],
+    lines: Union[str, Iterable[str]],
+    dir_path: Union[str, Path],
     file_name: str = "file_writer.txt",
     mode: str = "a+",
     separator: str = "\n",
     encoding: str = "utf-8",
     backup: bool = True,
-):
+) -> None:
     """向文件中写内容
 
     Args:
-        lines (str or list): 可以是单个字符串或者字符串的列表
-        dir_path (str or Path): 文件的绝对路径
-        file_name (str): 文件名称，有默认值
-        mode (str): 写文件的的模式，默认为 a+
-        separator (str): 每一行末尾的分隔符，有默认值
-        encoding (str): 文件的编码格式，默认为utf-8
-        backup (bool): 如果文件已经存在，是否对原文件进行备份，默认为True；
+        lines: 可以是单个字符串或者字符串的列表
+        dir_path: 文件的绝对路径
+        file_name: 文件名称，有默认值
+        mode: 写文件的的模式，默认为 a+
+        separator: 每一行末尾的分隔符，有默认值
+        encoding: 文件的编码格式，默认为utf-8
+        backup: 如果文件已经存在，是否对原文件进行备份，默认为True；
             如果为False，当文件已经存在的情况下，会追加到存在的文件中。
-
-    Returns:
-        None: 无返回值
     """
     dir_path: Path = Path(dir_path) if isinstance(dir_path, str) else dir_path
 
@@ -127,26 +126,22 @@ def file_writer(
                 file.write(line)
 
     print("## file_writer done...")
-    pass
 
 
 def read_txt_by_page(
     file_path: str,
-    parse_func: FunctionType,
+    parse_func: Callable[[list], None],
     page_size: int = 100,
     encoding: str = "utf-8",
-):
+) -> None:
     """
     从文本文件中分页读取内容
 
     Args:
-        file_path (str): 文件路径
-        parse_func (FunctionType): 每一页数据处理函数，必须定义
-        page_size (int): 每一页数据量
-        encoding (str): 文本文件的编码格式
-
-    Returns:
-        None: 在parse_func已经处理好数据，不用返回值
+        file_path: 文件路径
+        parse_func: 每一页数据处理函数，必须定义
+        page_size: 每一页数据量
+        encoding: 文本文件的编码格式
     """
     with open(file=file_path, encoding=encoding, mode="r") as file:
         data = list()
@@ -180,25 +175,22 @@ def read_txt_by_page(
 
 def read_txt_by_page_asyncio(
     file_path: str,
-    parse_func: FunctionType,
+    parse_func: Callable[[list], None],
     page_size: int = 100,
     encoding: str = "utf-8",
     open_async: bool = False,
     slave_num: int = 4,
-):
+) -> None:
     """
     从文本文件中分页读取内容，具备异步io处理功能
 
     Args:
-        file_path (str): 文件路径
-        parse_func (FunctionType): 每一页数据处理函数，必须定义
-        page_size (int): 每一页数据量
-        encoding (str): 文本文件的编码格式
-        open_async(bool): 是否开启异步io处理数据，默认不开启
-        slave_num(int): 执行任务的协程数目，默认为4
-
-    Returns:
-        None: 在parse_func已经处理好数据，不用返回值
+        file_path: 文件路径
+        parse_func: 每一页数据处理函数，必须定义
+        page_size: 每一页数据量
+        encoding: 文本文件的编码格式
+        open_async: 是否开启异步io处理数据，默认不开启
+        slave_num: 执行任务的协程数目，默认为4
     """
 
     async def parse_(loop, chunk):
@@ -253,16 +245,16 @@ def read_txt_by_page_asyncio(
     print(f"## All done. Total pages: {curr_page_id}. Elapsed time: {total_time}s")
 
 
-def read_content(file_path: Optional[str or PosixPath], encoding: str = "utf-8"):
+def read_content(file_path: Union[str, Path], encoding: str = "utf-8") -> List[dict]:
     """
     从文本文件中读取内容，将内容转换为list，list的元素为每行的字符串
 
     Args:
-        file_path (str or PosixPath): 文件路径
-        encoding (str): 文件的编码方式
+        file_path: 文件路径
+        encoding: 文件的编码方式
 
     Returns:
-        list: 每行字符串组成的列表
+        每行字符串组成的list
     """
     if isinstance(file_path, str):
         file_path = Path(file_path)
@@ -271,16 +263,16 @@ def read_content(file_path: Optional[str or PosixPath], encoding: str = "utf-8")
     )
 
 
-def read_jsons(file_path: Optional[str or PosixPath], encoding: str = "utf-8"):
+def read_jsons(file_path: Union[str, Path], encoding: str = "utf-8") -> List[dict]:
     """
     从存放json的文本文件中读取内容，并转化为dict组成的list
 
     Args:
-        file_path (str): 文件路径
-        encoding (str): 文件的编码方式
+        file_path: 文件路径
+        encoding: 文件的编码方式
 
     Returns:
-        list: dict组成的list
+        dict组成的list
     """
     if isinstance(file_path, str):
         file_path = Path(file_path)
